@@ -2,7 +2,7 @@
 #  SPDX-License-Identifier: Apache-2.0
 
 
-cost = "service.main.cost"
+cost = "service.attributes.main.cost"
 service_license = "service.attributes.main.license"
 sample = "service.attributes.additionalInformation.links.type"
 categories = "service.attributes.additionalInformation.categories"
